/*******************************************************************************
* \file     PowerMonitor.h
* \version  2.10
*
* \brief Provides the source code to the API for the PowerMonitor Component.
*
* Note:
*
********************************************************************************
* \copyright
* (c) 2015-2016, Cypress Semiconductor Corporation. All rights reserved.
* This software, including source code, documentation and related
* materials ("Software"), is owned by Cypress Semiconductor
* Corporation ("Cypress") and is protected by and subject to worldwide
* patent protection (United States and foreign), United States copyright
* laws and international treaty provisions. Therefore, you may use this
* Software only as provided in the license agreement accompanying the
* software package from which you obtained this Software ("EULA").
* If no EULA applies, Cypress hereby grants you a personal, non-exclusive,
* non-transferable license to copy, modify, and compile the
* Software source code solely for use in connection with Cypress's
* integrated circuit products. Any reproduction, modification, translation,
* compilation, or representation of this Software except as specified
* above is prohibited without the express written permission of Cypress.
* Disclaimer: THIS SOFTWARE IS PROVIDED AS-IS, WITH NO
* WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING,
* BUT NOT LIMITED TO, NON-INFRINGEMENT, IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
* PARTICULAR PURPOSE. Cypress reserves the right to make
* changes to the Software without notice. Cypress does not assume any
* liability arising out of the application or use of the Software or any
* product or circuit described in the Software. Cypress does not
* authorize its products for use in any products where a malfunction or
* failure of the Cypress product may reasonably be expected to result in
* significant property damage, injury or death ("High Risk Product"). By
* including Cypress's product in a High Risk Product, the manufacturer
* of such system or application assumes all risk of such use and in doing
* so agrees to indemnify Cypress against all liability.
*******************************************************************************/

#if !defined(CY_POWERMONITOR_PowerMonitor_H)
#define CY_POWERMONITOR_PowerMonitor_H

#define PowerMonitor_USE_DMAC      (1u)
#define PowerMonitor_CHECK_PGOOD   (0u)
    
#include "cytypes.h"
#include "CyLib.h"
#include "PowerMonitor_ADC.h"
#include "PowerMonitor_ADC_IRQ.h"

#if (PowerMonitor_USE_DMAC == 1)
    #include "PowerMonitor_uv_isr.h"
    #include "PowerMonitor_ov_isr.h"
    #include "PowerMonitor_DMA_Check.h"
    #include "PowerMonitor_DMA_Sample.h"
    #include "PowerMonitor_DMA_LimitUV.h"
    #include "PowerMonitor_DMA_LimitOV.h"
    #include "PowerMonitor_DMA_Enable.h"
#endif

#if (PowerMonitor_CHECK_PGOOD == 1)
    #include "PowerMonitor_PGood_Control_Reg.h"
    
    #if !defined(PowerMonitor_PGood_Control_Reg_Sync_ctrl_reg__REMOVED)
        #define PowerMonitor_USE_PGOOD (1)
    #endif  /* (PowerMonitor_PGood_Control_Reg_Sync_ctrl_reg__REMOVED) */
#else
    #define PowerMonitor_USE_PGOOD (0)
#endif /*(PowerMonitor_USE_PGOOD == 1)*/

extern cyisraddress CyRamVectors[CYINT_IRQ_BASE + CY_NUM_INTERRUPTS];

/******************************************************************************
* Parameter Defaults
*******************************************************************************/
/* Default config values from user parameters */
/** \addtogroup group_globals
    \{ */
/** Number of converters to be monitored.  Range 1 to 8. */
#define PowerMonitor_NUM_CONVERTERS                  (3u)
/** ADC maximum voltage in mV. Depends on the range chosen in the customizer. */
#define PowerMonitor_ADC_MAX_VOLTAGE                 (2048)
/** ADC maximum number of counts. Depends on the resolution of the ADC. */
#define PowerMonitor_ADC_MAX_COUNTS                  ((uint32)(1uL << PowerMonitor_ADC_MAX_RESOLUTION) - 1uL)
/** \} globals */

#define PowerMonitor_UDB_PRESENT                     (1u)
#define PowerMonitor_PGOOD_CONFIG                    (2u)

#define PowerMonitor_DEFAULT_OV_FAULT_MODE           (1u)
#define PowerMonitor_DEFAULT_UV_FAULT_MODE           (1u)
#define PowerMonitor_DEFAULT_OV_WARN_MODE            (1u)
#define PowerMonitor_DEFAULT_UV_WARN_MODE            (1u)

#define PowerMonitor_SAMPLE_AVERAGED                 (1u)
#define PowerMonitor_VREF_SELECT                     (3u)
#define PowerMonitor_VREF_VALUE                      (1024u)
#define PowerMonitor_ENABLE_DMA                      (1u)
#define PowerMonitor_EXPOSE_SOC                      (0u)

#define PowerMonitor_ADC_SCAN_NS                     (8750u)
#define PowerMonitor_RSP_TIME_NS                     (21249u)
#define PowerMonitor_ADC_CLK_DIV                     (3u)
#define PowerMonitor_ADC_CLK_A                       (32u)
#define PowerMonitor_ADC_CLK_B                       (32u)
#define PowerMonitor_ADC_CLK_C                       (32u)
#define PowerMonitor_ADC_CLK_D                       (2u)

/******************************************************************************
* Parameter Defaults
*******************************************************************************/
#if (PowerMonitor_USE_DMAC == 1)
    /* Datapath Registers */
    #define PowerMonitor_HwComp_A0_REG         (*(reg16 *) PowerMonitor_HwComp_Comp_u0__16BIT_A0_REG )
    #define PowerMonitor_HwComp_A0_PTR         ( (reg16 *) PowerMonitor_HwComp_Comp_u0__16BIT_A0_REG )    
    #define PowerMonitor_HwComp_A1_REG         (*(reg8  *) PowerMonitor_HwComp_Comp_u0__A1_REG )
    #define PowerMonitor_HwComp_A1_PTR         ( (reg8  *) PowerMonitor_HwComp_Comp_u0__A1_REG )  
    #define PowerMonitor_HwComp_D0_REG         (*(reg16 *) PowerMonitor_HwComp_Comp_u0__16BIT_D0_REG )
    #define PowerMonitor_HwComp_D0_PTR         ( (reg16 *) PowerMonitor_HwComp_Comp_u0__16BIT_D0_REG )  
    #define PowerMonitor_HwComp_D1_REG         (*(reg16 *) PowerMonitor_HwComp_Comp_u0__16BIT_D1_REG )
    #define PowerMonitor_HwComp_D1_PTR         ( (reg16 *) PowerMonitor_HwComp_Comp_u0__16BIT_D1_REG )  
    #define PowerMonitor_HwComp_F0_REG         (*(reg16 *) PowerMonitor_HwComp_Comp_u0__16BIT_F0_REG )
    #define PowerMonitor_HwComp_F0_PTR         ( (reg16 *) PowerMonitor_HwComp_Comp_u0__16BIT_F0_REG ) 
    #define PowerMonitor_HwComp_F1_REG         (*(reg16 *) PowerMonitor_HwComp_Comp_u0__16BIT_F1_REG )
    #define PowerMonitor_HwComp_F1_PTR         ( (reg16 *) PowerMonitor_HwComp_Comp_u0__16BIT_F1_REG )  
#endif /* PowerMonitor_USE_DMAC */

/* Callback typedef */
typedef void (*PowerMonitor_callback)(uint32 converterNum, uint32 faultType);


/**
 \addtogroup group_globals 
 Globals are noted in the description of the functions that use 
 globals.
 \{
*/

/** Indicates whether the PowerMonitor has been initialized. */
extern uint32 PowerMonitor_initVar;

/** Array containing the UV fault threshold translated to ADC counts.*/
extern uint16 PowerMonitor_UVFaultThreshold_Count[PowerMonitor_NUM_CONVERTERS];
/** Array containing the OV fault threshold translated to ADC counts.*/
extern uint16 PowerMonitor_OVFaultThreshold_Count[PowerMonitor_NUM_CONVERTERS];
/** Array containing the UV warning threshold translated to ADC counts.*/
extern uint16 PowerMonitor_UVWarnThreshold_Count[PowerMonitor_NUM_CONVERTERS];
/** Array containing the OV warning threshold translated to ADC counts.*/
extern uint16 PowerMonitor_OVWarnThreshold_Count[PowerMonitor_NUM_CONVERTERS];

/** Array containing the voltage scaling factors. It is calculated in the 
following format:

Y = Scale Factor x 2^16 x ADC Max Counts / ADC Max Voltage (mV)
*/
extern const uint32 PowerMonitor_VoltageScalingFactor[PowerMonitor_NUM_CONVERTERS];

/** Array containing the count scaling factors. It should be calculated in the 
following format:
Y = 2^16 / Scale Factor ADC Max Voltage (mV) / ADC Max Counts
*/
extern const uint32 PowerMonitor_CountScalingFactor[PowerMonitor_NUM_CONVERTERS];

/** Indicates what kind of faults are currently enabled for each of the converters. */
extern uint8 PowerMonitor_faultEnable[PowerMonitor_NUM_CONVERTERS]; 

/** Holds the under voltage warning status for each of the power converters. */
extern volatile uint32 PowerMonitor_UVWarnStatus;
/** Holds the over voltage warning status for each of the power converters. */
extern volatile uint32 PowerMonitor_OVWarnStatus;
/** Holds the under voltage fault status for each of the power converters. */
extern volatile uint32 PowerMonitor_UVFaultStatus;
/** Holds the over voltage fault status for each of the power converters. */
extern volatile uint32 PowerMonitor_OVFaultStatus;

/** Holds the PGood Status for each of the power converter. */ 
extern volatile uint32 PowerMonitor_PGoodStatus;

/** Internal register controlling which faults are active. */
extern volatile uint8 PowerMonitor_faultConfig[PowerMonitor_NUM_CONVERTERS];

 /** \} globals */

extern const uint32 PowerMonitor_UVFaultThresholdInit_mV[PowerMonitor_NUM_CONVERTERS];
extern const uint32 PowerMonitor_UVWarnThresholdInit_mV[PowerMonitor_NUM_CONVERTERS];
extern const uint32 PowerMonitor_OVWarnThresholdInit_mV[PowerMonitor_NUM_CONVERTERS];
extern const uint32 PowerMonitor_OVFaultThresholdInit_mV[PowerMonitor_NUM_CONVERTERS];
extern const uint32 PowerMonitor_AdcClockSelect[PowerMonitor_NUM_CONVERTERS];

extern uint32 PowerMonitor_UVFaultThreshold_mV[PowerMonitor_NUM_CONVERTERS];
extern uint32 PowerMonitor_OVFaultThreshold_mV[PowerMonitor_NUM_CONVERTERS];
extern uint32 PowerMonitor_UVWarnThreshold_mV[PowerMonitor_NUM_CONVERTERS];
extern uint32 PowerMonitor_OVWarnThreshold_mV[PowerMonitor_NUM_CONVERTERS];

extern uint32 PowerMonitor_samplesAveraged;
extern uint32 PowerMonitor_converterCounts[PowerMonitor_NUM_CONVERTERS];

/* ISS callbacks. */
extern PowerMonitor_callback faultCallback;

#if (PowerMonitor_USE_DMAC == 1)
    extern volatile uint8 PowerMonitor_isDmaTriggered;
#endif /* PowerMonitor_USE_DMAC */
    
/******************************************************************************
* Function Prototypes
*******************************************************************************/

/** \addtogroup group_init 
    \{ */
void PowerMonitor_Start(void);
void PowerMonitor_Stop (void);
void PowerMonitor_Init(void);
void PowerMonitor_Enable(void);
 /** \} init */
 
/** \addtogroup group_general
    \{ */
void PowerMonitor_EnableFault(uint32 converterMask);
void PowerMonitor_DisableFault(uint32 converterMask);
void PowerMonitor_SetFaultMode(uint32 converterNum, uint32 faultMode);
uint32 PowerMonitor_GetFaultMode(uint32 converterNum);
uint32 PowerMonitor_GetPGoodStatus(void);

uint32 PowerMonitor_GetFaultSource(void);
uint32 PowerMonitor_GetOVFaultStatus(void);
uint32 PowerMonitor_GetUVFaultStatus(void);
uint32 PowerMonitor_GetOVWarnStatus(void);
uint32 PowerMonitor_GetUVWarnStatus(void);

cystatus PowerMonitor_SetUVWarnThreshold(uint32 converterNum, uint32 uvWarnThreshold_mV);
uint32 PowerMonitor_GetUVWarnThreshold(uint32 converterNum);
cystatus PowerMonitor_SetOVWarnThreshold(uint32 converterNum, uint32 ovWarnThreshold_mV);
uint32 PowerMonitor_GetOVWarnThreshold(uint32 converterNum);

cystatus PowerMonitor_SetUVFaultThreshold(uint32 converterNum, uint32 uvFaultThreshold_mV);
uint32 PowerMonitor_GetUVFaultThreshold(uint32 converterNum);
cystatus PowerMonitor_SetOVFaultThreshold(uint32 converterNum, uint32 ovFaultThreshold_mV);
uint32 PowerMonitor_GetOVFaultThreshold(uint32 converterNum);

uint32 PowerMonitor_GetConverterVoltage(uint32 converterNum);
cystatus PowerMonitor_SetSamplesAveraged(uint32 numSample);
uint32 PowerMonitor_GetSamplesAveraged(void);

void PowerMonitor_SetFaultCallbackFunction(PowerMonitor_callback func);
/** \} general */

#if (PowerMonitor_USE_DMAC == 1)
    /** \addtogroup group_interrupts
        \{*/
    CY_ISR_PROTO(PowerMonitor_Uv_ISR_Handler);
    CY_ISR_PROTO(PowerMonitor_Ov_ISR_Handler);
    CY_ISR_PROTO(PowerMonitor_ADC_DMA_ISR);
        /** \} interrupts */
#endif /* PowerMonitor_USE_DMAC */

/******************************************************************************
* API Constants
*******************************************************************************/
/* OV and UV Masks */
#define PowerMonitor_OV_MASK                       (1u)
#define PowerMonitor_UV_MASK                       (2u)

/* Default warn and fault modes */
#define PowerMonitor_WARN_MODE_MASK                (3u)
#define PowerMonitor_FAULT_MODE_MASK               (3u)

#define PowerMonitor_DEFAULT_WARN_MODE             (PowerMonitor_DEFAULT_OV_WARN_MODE | \
                                                          (uint8)(PowerMonitor_DEFAULT_UV_WARN_MODE << 1u))
#define PowerMonitor_DEFAULT_FAULT_MODE            (PowerMonitor_DEFAULT_OV_FAULT_MODE | \
                                                          (uint8)(PowerMonitor_DEFAULT_UV_FAULT_MODE << 1u))

/* Constants for PowerMonitor_faultConfig values. */
#define PowerMonitor_ENABLE_CONVERTER_NUM_MSK      (0x1Fu)
#define PowerMonitor_ENABLE_OV_MASK                (0x20u)
#define PowerMonitor_ENABLE_OV_SHIFT               (5u)
#define PowerMonitor_ENABLE_UV_MASK                (0x40u)
#define PowerMonitor_ENABLE_UV_SHIFT               (6u)
#define PowerMonitor_ENABLE_FAULT_MASK             (0x80u)

#define PowerMonitor_MAX_SAMPLES_BIT               (8u)
#define PowerMonitor_MAX_SAMPLES                   (0x100u)

/* Constants for Scaling factor*/
#define PowerMonitor_SCALE_ROUNDING                (0x8000u)
#define PowerMonitor_SCALE_DIVIDE                  (16u)

/* Interrupt Number of the ADC_IRQ interrupt. */
#define PowerMonitor_IRQ__INTC_NUMBER              (PowerMonitor_ADC_IRQ__INTC_NUMBER)

/* Interrupt macros. */
#define CY_INT_NUMBER_MASK                             (0u)
#define PowerMonitor_IntDisable(irqNum) \
    do { \
        *(uint32*)CY_INT_CLEAR_PTR = \
        (uint32)(1ul << (CY_INT_NUMBER_MASK & (irqNum))); \
    } while(0)
#define PowerMonitor_IntEnable(irqNum) \
    do { \
        *(uint32*)CY_INT_ENABLE_PTR = \
        (uint32)(1ul << (CY_INT_NUMBER_MASK & (irqNum))); \
    } while(0)

/* Macro for function that just returns variable */
#define PowerMonitor_GetSamplesAveraged() (PowerMonitor_samplesAveraged)

/* Powermonitor enable state macro. */
#define PowerMonitor_ENABLED  ((PowerMonitor_ADC_SAR_CTRL_REG & PowerMonitor_ADC_ENABLE))


#endif /* CY_POWERMONITOR_PowerMonitor_H */

/* [] END OF FILE */
