/*******************************************************************************
* File Name: PowerMonitor_1_ADC_PM.c
* Version 2.50
*
* Description:
*  This file provides Sleep/WakeUp APIs functionality.
*
* Note:
*
********************************************************************************
* Copyright 2008-2017, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "PowerMonitor_1_ADC.h"


/***************************************
* Local data allocation
***************************************/

static PowerMonitor_1_ADC_BACKUP_STRUCT  PowerMonitor_1_ADC_backup =
{
    PowerMonitor_1_ADC_DISABLED,
    0u    
};


/*******************************************************************************
* Function Name: PowerMonitor_1_ADC_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void PowerMonitor_1_ADC_SaveConfig(void)
{
    /* All configuration registers are marked as [reset_all_retention] */
}


/*******************************************************************************
* Function Name: PowerMonitor_1_ADC_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void PowerMonitor_1_ADC_RestoreConfig(void)
{
    /* All configuration registers are marked as [reset_all_retention] */
}


/*******************************************************************************
* Function Name: PowerMonitor_1_ADC_Sleep
********************************************************************************
*
* Summary:
*  Stops the ADC operation and saves the configuration registers and component
*  enable state. Should be called just prior to entering sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  PowerMonitor_1_ADC_backup - modified.
*
*******************************************************************************/
void PowerMonitor_1_ADC_Sleep(void)
{
    /* During deepsleep/ hibernate mode keep SARMUX active, i.e. do not open
    *   all switches (disconnect), to be used for ADFT
    */
    PowerMonitor_1_ADC_backup.dftRegVal = PowerMonitor_1_ADC_SAR_DFT_CTRL_REG & (uint32)~PowerMonitor_1_ADC_ADFT_OVERRIDE;
    PowerMonitor_1_ADC_SAR_DFT_CTRL_REG |= PowerMonitor_1_ADC_ADFT_OVERRIDE;
    if((PowerMonitor_1_ADC_SAR_CTRL_REG  & PowerMonitor_1_ADC_ENABLE) != 0u)
    {
        if((PowerMonitor_1_ADC_SAR_SAMPLE_CTRL_REG & PowerMonitor_1_ADC_CONTINUOUS_EN) != 0u)
        {
            PowerMonitor_1_ADC_backup.enableState = PowerMonitor_1_ADC_ENABLED | PowerMonitor_1_ADC_STARTED;
        }
        else
        {
            PowerMonitor_1_ADC_backup.enableState = PowerMonitor_1_ADC_ENABLED;
        }
        PowerMonitor_1_ADC_StopConvert();
        PowerMonitor_1_ADC_Stop();
        
        /* Disable the SAR internal pump before entering the chip low power mode */
        if((PowerMonitor_1_ADC_SAR_CTRL_REG & PowerMonitor_1_ADC_BOOSTPUMP_EN) != 0u)
        {
            PowerMonitor_1_ADC_SAR_CTRL_REG &= (uint32)~PowerMonitor_1_ADC_BOOSTPUMP_EN;
            PowerMonitor_1_ADC_backup.enableState |= PowerMonitor_1_ADC_BOOSTPUMP_ENABLED;
        }
    }
    else
    {
        PowerMonitor_1_ADC_backup.enableState = PowerMonitor_1_ADC_DISABLED;
    }
}


/*******************************************************************************
* Function Name: PowerMonitor_1_ADC_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component enable state and configuration registers.
*  This should be called just after awaking from sleep mode.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  PowerMonitor_1_ADC_backup - used.
*
*******************************************************************************/
void PowerMonitor_1_ADC_Wakeup(void)
{
    PowerMonitor_1_ADC_SAR_DFT_CTRL_REG = PowerMonitor_1_ADC_backup.dftRegVal;
    if(PowerMonitor_1_ADC_backup.enableState != PowerMonitor_1_ADC_DISABLED)
    {
        /* Enable the SAR internal pump  */
        if((PowerMonitor_1_ADC_backup.enableState & PowerMonitor_1_ADC_BOOSTPUMP_ENABLED) != 0u)
        {
            PowerMonitor_1_ADC_SAR_CTRL_REG |= PowerMonitor_1_ADC_BOOSTPUMP_EN;
        }
        PowerMonitor_1_ADC_Enable();
        if((PowerMonitor_1_ADC_backup.enableState & PowerMonitor_1_ADC_STARTED) != 0u)
        {
            PowerMonitor_1_ADC_StartConvert();
        }
    }
}
/* [] END OF FILE */
